@@ -32,10 +32,8 @@ class Policy(object):
     installation as open-ish, or closed-ish.
     """
 
-    attributes = [
-            'read', 'write', 'create', 'delete', 'manage',
-            'accept', 'owner'
-            ]
+    attributes = ['read', 'write', 'create', 'delete', 'manage', 'accept',
+            'owner']
 
     def __init__(self, owner=None,
             read=None, write=None, create=None, delete=None,
