@@ -182,7 +182,7 @@ class Store(StorageInterface):
             # set created on new tiddler from modified on base_tiddler
             # (might be the same)
             tiddler.created = base_tiddler.modified
-            if tiddler.type and tiddler.type != 'None':
+            if tiddler.type and tiddler.type != 'None' and not tiddler.type.startswith('text/'):
                 tiddler.text = b64decode(tiddler.text.lstrip().rstrip())
             return tiddler
         except IOError, exc:
@@ -213,7 +213,7 @@ class Store(StorageInterface):
         revision = self._tiddler_revision_filename(tiddler) + 1
         tiddler_filename = self._tiddler_full_filename(tiddler, revision)
 
-        if tiddler.type and tiddler.type != 'None':
+        if tiddler.type and tiddler.type != 'None' and not tiddler.type.startswith('text/'):
             tiddler.text = b64encode(tiddler.text)
         self.serializer.object = tiddler
         write_utf8_file(tiddler_filename, self.serializer.to_string())
@@ -323,12 +323,13 @@ class Store(StorageInterface):
         Search in the store for tiddlers that match search_query.
         This is intentionally simple, slow and broken to encourage overriding.
         """
-        bags = self._bag_filenames()
+        bag_filenames = self._bag_filenames()
         found_tiddlers = []
 
         query = search_query.lower()
 
-        for bagname in bags:
+        for bagname in bag_filenames:
+            bagname = urllib.unquote(bagname).decode('utf-8')
             tiddler_dir = self._tiddlers_dir(bagname)
             tiddler_files = self._files_in_dir(tiddler_dir)
             for tiddler_name in tiddler_files:
